from fei_crypto.env import env
import typer
from dotenv import load_dotenv

load_dotenv(".env")

def main(env_name: str):
    print(f'{env_name}🧊: {env(env_name)}')


def run():
    typer.run(main)


if __name__ == '__main__':
    typer.run(main)



import logging

import dotenv

print("🐞  You have imported tests module  🐞")
dotenv.load_dotenv("d:/.env")
# Enable logging
logging.basicConfig(
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s", level=logging.INFO
)
# set higher logging level for httpx to avoid all GET and POST requests being logged
logging.getLogger("httpx").setLevel(logging.WARNING)



import logging
from rich.logging import RichHandler
if __name__ == '__main__':
    logging.basicConfig(
        level=logging.DEBUG,
        format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
    )

    logging.debug('debug 信息')
    logging.warning('warning 输出,默认级别是warning')
    logging.info('info 信息')



import datetime
import time


def dt():
    return datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')


def seconds():
    return round(time.time())


def milliseconds():
    return round(time.time() * 1000)


def microseconds():
    return round(time.time() * 1000 * 1000)

def nanoseconds():
    return round(time.time() * 1000 * 1000 * 1000)



def enumerate_print(src: str) -> None:
    for i, c in enumerate(src):
        if c != ' ':
            print('idx【{0}】,item【{1}】'.format(i, c))


if __name__ == '__main__':
    print('__main__'.title())
    t2cDict: dict = {}
    for idx, item in enumerate("Hello World!"):
        if item != ' ':
            t2cDict['[{0}:{1}]'.format(idx, idx + 1)] = "#111111"


    print(t2cDict)
    print("🔆🔅💯💹📈📉")

    s = None

    print(isinstance(s, str))


import os

from PIL import Image
from statistics import mean
from itertools import product
import typer


def rmw(file_path: str, colors: int = 3) -> str:
    img = Image.open(file_path)
    avg = take_color_avg(img, colors)
    width, height = img.size

    for pos in product(range(width), range(height)):
        if sum(img.getpixel(pos)[:3]) > 615 and avg > 381:
            img.putpixel(pos, (255, 255, 255))

        if sum(img.getpixel(pos)[:3]) < 150 and avg <= 381:
            img.putpixel(pos, (0, 0, 0))

    file_name, file_ext = os.path.splitext(file_path)
    new_file_name = file_name + '_rmw' + file_ext
    img.save(new_file_name)
    print(new_file_name)
    return new_file_name


def take_color_avg(img: Image, c: int) -> int:
    small_image = img.resize((80, 80))
    result = small_image.convert(
        "P", palette=Image.ADAPTIVE, colors=c
    )

    palette = result.getpalette()
    color_counts = sorted(result.getcolors(), reverse=True)
    colors = list()

    for i in range(c):
        palette_index = color_counts[i][1]
        dominant_color = palette[palette_index * 3: palette_index * 3 + 3]
        colors.append(tuple(dominant_color))

    color_sum = list(map(sum, colors))
    return mean(color_sum)


if __name__ == '__main__':
    typer.run(rmw)



from typing import Sequence

from telethon.client import TelegramClient
from telethon.hints import EntityLike

from tg.config import CONFIG
from tg.plugin_models import FileType
from tg.utils import cleanup, stamp
from telethon.tl.custom.message import Message


class TgMessage:
    def __init__(self, message: Message) -> None:
        self.message = message
        self.text = self.message.text
        self.raw_text = self.message.raw_text
        self.sender_id = self.message.sender_id
        self.file_type = self.guess_file_type()
        self.new_file = None
        self.cleanup = False
        self.reply_to = None
        self.file = None

    async def get_file(self) -> str:
        """Downloads the file in the message and returns the path where its saved."""
        if self.file_type == FileType.NOFILE:
            raise FileNotFoundError("No file exists in this message.")
        self.file = stamp(await self.message.download_media(""), self.sender_id)
        return self.file

    def guess_file_type(self) -> FileType:
        for f in FileType:
            if f == FileType.NOFILE:
                return f
            try:
                obj = getattr(self.message, f.value)
            except AttributeError:
                continue
            if obj:
                return f

    def clear(self) -> None:
        if self.new_file and self.cleanup:
            cleanup(self.new_file)
            self.new_file = None


async def send_message(recipient: EntityLike, tm: TgMessage) -> Sequence[Message] | Message:
    """Forward or send a copy, depending on config."""
    client: TelegramClient = tm.message.client
    sender = await tm.message.get_sender()

    if tm.message.is_group:
        last_name = ''
        if sender.last_name is not None and sender.last_name != '':
            last_name = ' ' + sender.last_name
        from_user = f'【{sender.first_name}{last_name}】'
        tm.text = from_user + tm.text

    if CONFIG.show_forwarded_from:
        return await client.forward_messages(recipient, tm.message)
    if tm.new_file:
        message = await client.send_file(
            recipient, tm.new_file, caption=tm.text, reply_to=tm.reply_to
        )
        return message
    tm.message.text = tm.text
    return await client.send_message(recipient, tm.message, reply_to=tm.reply_to)



import base64

from tests import *
import os
import redis

if __name__ == '__main__':
    r = redis.Redis(
        host='192.168.123.11',
        port=6379,
        password=os.getenv('REDIS_PASSWORD'),
        db=0)
    with open("d:/BaiduSyncdisk/assets/png/koltime/koltime_menu_bot.png", "rb") as f:
        base64_data = base64.b64encode(f.read()).decode()
        r.hsetnx('koltime_menu_bot', 'pic_base64', base64_data)

    caption = """
🎉 欢迎您来到koltime社区

📈 我们是华语₿圈信息聚合平台

🦄 50+全球优质博主会员信息 
🦄 100+频道即时同步、7x24小时更新 
🦄 价值2万U的教学视频  
🦄 信息即时翻译、无障碍浏览国内外优质内容
🦄 定期淘汰表现不佳的博主，无需担心踩雷  
🦄 1年+稳定不间断运行 

✨✨✨ 一切尽在koltime!
    """
    r.hsetnx('koltime_menu_bot', 'description', caption)
    r.hsetnx('koltime_menu_bot', 'pic_url', 'https://arweave.net/DZ_ZI6r4pfVP5u0e-lCOGESM4JMjN0OPXVrgyZLrU8U')
    description = r.hget('koltime_menu_bot', 'description')
    print(type(description))
    if isinstance(description, bytes):
        print(description.decode())

    # r.hsetnx('koltime_menu_bot', 'pic', pic)
    # print(r.hget('koltime_menu_bot', 'desc'))



from manim import *


class SquareToCircle(Scene):
    def construct(self):
        circle = Circle()
        square = Square()
        square.flip(RIGHT)
        square.rotate(-3 * TAU / 8)
        circle.set_fill(PINK, opacity=0.5)

        self.play(Create(square))
        self.play(Transform(square, circle))
        self.play(FadeOut(square))


class Basic(Scene):
    def __init__(self, t: str):
        # config["frame_height"] = config["frame_height"]/2
        # config["frame_width"] = config["frame_width"] / 2
        # config["pixel_width"] = config["pixel_width"] / 2
        config["pixel_width"] = 900
        config["pixel_height"] = 160

        super().__init__()
        t2c_dict: dict = {}
        for i, c in enumerate(t):
            if c != ' ':
                r_color = random_color()
                if str(r_color) == '#000000':
                    r_color = '#ffffff'

                t2c_dict['[{0}:{1}]'.format(i, i + 1)] = r_color

        mtext = Text(t, t2c=t2c_dict, fill_opacity=1, weight='BOLD')
        self.play(Create(mtext))
        self.play(mtext.animate.scale(2))

        self.wait()


class Dz(Scene):
    def construct(self):
        text1 = Text(
            'Disneyland', font_size=60)
        text2 = Text(
            'Disneyland', font_size=60)
        self.play(Write(text2.shift(DOWN * 1)), Create(text1))
        self.wait()


if __name__ == '__main__':
    text = "1000PEOPLE-USDT"
    with tempconfig(
            {'quality': 'low_quality', 'preview': True, 'output_file': '2', 'format': 'gif'}):
        scene = Basic(t=text)
        scene.render()



import os

from discord_webhook import DiscordWebhook, DiscordEmbed


def send(webhook_url: str, text: str = "", file_paths: str = "", proxy: str = None) -> None:
    proxies = None
    if proxy is not None:
        proxies = {
            "http": proxy,
            "https": proxy,
        }

    webhook = DiscordWebhook(url=webhook_url, content=text, proxies=proxies)
    for fi_path in str.split(file_paths, ",", -1):
        fi_path = str.strip(fi_path)
        if fi_path == "":
            continue
        with open(fi_path, "rb") as f:
            webhook.add_file(file=f.read(), filename=os.path.basename(fi_path))

    print(webhook.execute())


if __name__ == "__main__":
    send(
        "",
        "交易方向:平多🚀\n平仓均价:0.8605197740112994\n已实现收益率:📉-35.74%\n识别ID:2DEB3930217A4ECAB35A3BDBDB14D96B\n"
        "触发时间:2024-03-29 15:09:45\n\n⬆️   🔴🟠🟤🟣🔵🟢🟡   ⬆️",
        "e:/github/feicrypto/fei-crypto-python/media/videos/360p15/btc.mp4,"
        "e:/github/feicrypto/fei-crypto-python/media/videos/360p15/people.mp4,"
        "e:/github/feicrypto/fei-crypto-python/media/videos/360p15/pepe.mp4",
    )



from telethon import TelegramClient, events, functions, types
from tg.bot import get_events
from tg import config, const
import logging
from tg import storage as st
from tg.message import send_message
from tg.plugins import apply_plugins


async def new_message_handler(event) -> None:
    chat_id = event.chat_id

    if chat_id not in config.from_to:
        return
    logging.info(f"New message received in {chat_id}")
    event_uid = st.EventUid(event)  # chart_id msg_id
    length = len(st.stored)
    exceeding = length - const.KEEP_LAST_MANY
    # stored dict 超过储存大小,删除旧数据
    if exceeding > 0:
        for key in st.stored:
            del st.stored[key]
            break

    dest = config.from_to.get(chat_id)
    tm = await apply_plugins(event.message)
    if not tm:
        return

    r_event_uid = None
    if event.is_reply:
        r_event = st.DummyEvent(chat_id, event.reply_to_msg_id)
        r_event_uid = st.EventUid(r_event)

    st.stored[event_uid] = {}
    for d in dest:
        if event.is_reply and r_event_uid in st.stored:
            tm.reply_to = st.stored.get(r_event_uid).get(d)
        fwded_msg = await send_message(d, tm)
        st.stored[event_uid].update({d: fwded_msg})
    tm.clear()


async def deleted_message_handler(event):
    chat_id = event.chat_id
    if chat_id not in config.from_to:
        return

    logging.info(f"🛩️ids:{event.deleted_ids}💢deleted in {chat_id}")

    for item in event.deleted_ids:
        event.id = item
        event_uid = st.EventUid(event)
        fwded_msgs = st.stored.get(event_uid)
        if fwded_msgs:
            for _, msg in fwded_msgs.items():
                await msg.delete()


async def edited_message_handler(event) -> None:
    message = event.message
    chat_id = event.chat_id
    if chat_id not in config.from_to:
        return

    logging.info(f"Message edited in {chat_id}")

    event_uid = st.EventUid(event)

    tm = await apply_plugins(message)

    if not tm:
        return

    fwded_msgs = st.stored.get(event_uid)

    if fwded_msgs:
        for _, msg in fwded_msgs.items():
            if config.CONFIG.live.delete_on_edit == message.text:
                await msg.delete()
                await message.delete()
            else:
                await msg.edit(tm.text)
        return

    dest = config.from_to.get(chat_id)

    for d in dest:
        await send_message(d, tm)
    tm.clear()


ALL_EVENTS = {
    "new": (new_message_handler, events.NewMessage()),
    "edited": (edited_message_handler, events.MessageEdited()),
    "deleted": (deleted_message_handler, events.MessageDeleted()),
}


async def start_sync(client: TelegramClient) -> None:
    me = await client.get_me()
    print(f'🛩️usd_id:{me.id}')
    print(f'🛩️usename:{me.username}')
    config.is_bot = await client.is_bot()
    print(f'🛩️is_bot:{config.is_bot}')
    command_events = get_events()

    await config.load_admins(client)

    ALL_EVENTS.update(command_events)

    for key, val in ALL_EVENTS.items():
        if config.CONFIG.live.delete_sync is False and key == "deleted":
            continue
        client.add_event_handler(*val)
        logging.info(f"Added event handler for {key}")

    if config.is_bot and const.REGISTER_COMMANDS:
        await client(
            functions.bots.SetBotCommandsRequest(
                scope=types.BotCommandScopeDefault(),
                lang_code="en",
                commands=[
                    types.BotCommand(command=key, description=value)
                    for key, value in const.COMMANDS.items()
                ],
            )
        )
    config.from_to = await config.load_from_to(client, config.CONFIG.forwards)
    await client.run_until_disconnected()



"""Load all user defined config and env vars."""

import logging
import os
import sys
from typing import Dict, List, Optional, Union

from pydantic import BaseModel, validator
from pymongo import MongoClient
from telethon import TelegramClient
from telethon.sessions import StringSession

from tg import storage as stg
from tg.plugin_models import PluginConfig

# pwd = os.getcwd()
# env_file = os.path.join(pwd, ".env")
# load_dotenv(env_file)

CONFIG_FILE_NAME = ""


class Forward(BaseModel):
    """Blueprint for the forward object."""

    # pylint: disable=too-few-public-methods
    con_name: str = ""
    use_this: bool = True
    source: Union[int, str] = ""
    dest: List[Union[int, str]] = []
    offset: int = 0
    end: Optional[int] = 0


class LiveSettings(BaseModel):
    # pylint: disable=too-few-public-methods
    sequential_updates: bool = False
    delete_sync: bool = False
    delete_on_edit: Optional[str] = ".deleteMe"


class PastSettings(BaseModel):
    """Configuration for past mode."""

    # pylint: disable=too-few-public-methods
    delay: int = 0

    @validator("delay")
    def validate_delay(cls, val):  # pylint: disable=no-self-use,no-self-argument
        """Check if the delay used by user is values. If not, use closest logical values."""
        if val not in range(0, 101):
            logging.warning("delay must be within 0 to 100 seconds")
            if val > 100:
                val = 100
            if val < 0:
                val = 0
        return val


class LoginConfig(BaseModel):
    API_ID: int = 0
    API_HASH: str = ""
    user_type: int = 0  # 0:bot, 1:user
    phone_no: int = 86
    USERNAME: str = ""
    SESSION_STRING: str = ""
    BOT_TOKEN: str = ""
    PROXY: str = ""


class BotMessages(BaseModel):
    start: str = "Hi! I am alive"
    bot_help: str = "For details visit https://pypi.org/project/fei-crypto"


class Config(BaseModel):
    # pylint: disable=too-few-public-
    pid: int = 0
    login: LoginConfig = LoginConfig()
    admins: List[Union[int, str]] = []
    forwards: List[Forward] = []
    show_forwarded_from: bool = False
    mode: int = 0  # 0: live, 1:past
    live: LiveSettings = LiveSettings()
    past: PastSettings = PastSettings()

    plugins: PluginConfig = PluginConfig()
    bot_messages = BotMessages()


def write_config_to_file(config: Config):
    with open(CONFIG_FILE_NAME, "w", encoding="utf8") as file:
        file.write(config.json())


def detect_config_type() -> int:
    if os.getenv("MONGO_CON_STR"):
        if MONGO_CON_STR:
            logging.info("Using mongo db for storing config!")
            client = MongoClient(MONGO_CON_STR)
            stg.mycol = setup_mongo(client)
        return 2
    if os.path.exists(CONFIG_FILE_NAME):
        logging.info(f"{CONFIG_FILE_NAME} detected!")
        return 1
    else:
        logging.info(
            "config file not found. mongo not found. creating local config file."
        )
        cfg = Config()
        write_config_to_file(cfg)
        logging.info(f"{CONFIG_FILE_NAME} created!")
        return 1


def read_config(count=1) -> Config:
    """Load the configuration defined by user."""
    if count > 3:
        logging.warning("Failed to read config, returning default config")
        return Config()
    if count != 1:
        logging.info(f"Trying to read config time:{count}")
    try:
        if stg.CONFIG_TYPE == 1:
            with open(CONFIG_FILE_NAME, encoding="utf8") as file:
                return Config.parse_raw(file.read())
        elif stg.CONFIG_TYPE == 2:
            return read_db()
        else:
            return Config()
    except Exception as err:
        logging.warning(err)
        stg.CONFIG_TYPE = detect_config_type()
        return read_config(count=count + 1)


def write_config(config: Config, persist=True):
    """Write changes in config back to file."""
    if stg.CONFIG_TYPE == 1 or stg.CONFIG_TYPE == 0:
        write_config_to_file(config)
    elif stg.CONFIG_TYPE == 2:
        if persist:
            update_db(config)


def get_env_var(name: str, optional: bool = False) -> str:
    """Fetch an env var."""
    var = os.getenv(name, "")

    while not var:
        if optional:
            return ""
        var = input(f"Enter {name}: ")
    return var


async def get_id(client: TelegramClient, peer):
    return await client.get_peer_id(peer)


async def load_from_to(
        client: TelegramClient, forwards: List[Forward]
) -> Dict[int, List[int]]:
    from_to_dict = {}

    async def _(peer):
        return await get_id(client, peer)

    for forward in forwards:
        if not forward.use_this:
            continue
        source = forward.source
        if type(source) != int and source.strip() == "":
            continue
        src = await _(forward.source)
        from_to_dict[src] = [await _(dest) for dest in forward.dest]
    logging.info(f"From to dict is {from_to_dict}")
    return from_to_dict


async def load_admins(client: TelegramClient):
    for admin in CONFIG.admins:
        ADMINS.append(await get_id(client, admin))
    logging.info(f"Loaded admins are {ADMINS}")
    return ADMINS


def get_session():
    if CONFIG.login.SESSION_STRING and CONFIG.login.user_type == 1:
        logging.info("using session string")
        session = StringSession(CONFIG.login.SESSION_STRING)
    elif CONFIG.login.BOT_TOKEN and CONFIG.login.user_type == 0:
        logging.info("using bot account")
        session = "bot"
    else:
        logging.warning("Login information not set!")
        sys.exit()
    return session


def setup_mongo(client):
    mydb = client[MONGO_DB_NAME]
    mycol = mydb[MONGO_COL_NAME]
    if not mycol.find_one({"_id": 0}):
        mycol.insert_one({"_id": 0, "author": "tg", "config": Config().dict()})

    return mycol


def update_db(cfg):
    stg.mycol.update_one({"_id": 0}, {"$set": {"config": cfg.dict()}})


def read_db():
    obj = stg.mycol.find_one({"_id": 0})
    cfg = Config(**obj["config"])
    return cfg


ADMINS = []

MONGO_CON_STR = os.getenv("MONGO_CON_STR")
MONGO_DB_NAME = os.getenv("MONGO_DB_NAME", "tg-config")
MONGO_COL_NAME = os.getenv("MONGO_COL_NAME", "tg-instance-0")

CONFIG: Config

from_to = {}
is_bot: Optional[bool] = None



import os
from datetime import datetime
from tg.utils import clean_session_files
import redis
import dotenv
from telegram.ext import (
    Application,
    CommandHandler,
    MessageHandler,
    ContextTypes,
    filters
)

from telegram import (
    Update,
    ReplyKeyboardMarkup,
    KeyboardButton)

PINDAO_TEXT = '📚频道列表'
XUEXI_TEXT = '🍿学习视频'
SHIYONG_TEXT = '🐝试用频道'
VIP_TEXT = '💎购买会员'
FANYONG_TEXT = '🍕返佣链接'
QUN_TEXT = '🙌社群链接'
FAQ_TEXT = '🤔疑问解答(FAQ❓)'
ENV_PREFIX = 'TG_KOLTIME_MENU_BOT_'

r: redis.client.Redis | None = None

score_dict: dict[float, str] = {
    1.0: '中文博主',
    2.0: '提阿非罗',
    3.0: '英文博主',
    4.0: 'koltime',
    5.0: '其他',
}


async def start(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    keyboard = [
        [
            KeyboardButton(PINDAO_TEXT),
            KeyboardButton(XUEXI_TEXT),
        ],
        [
            KeyboardButton(SHIYONG_TEXT),
            KeyboardButton(VIP_TEXT),
        ],
        [
            KeyboardButton(FANYONG_TEXT),
            KeyboardButton(QUN_TEXT),
        ], [
            KeyboardButton(FAQ_TEXT)
        ]
    ]

    reply_markup = ReplyKeyboardMarkup(keyboard)

    description = r.hget('koltime_menu_bot', 'description')
    caption = 'welcome!'
    if isinstance(description, bytes):
        caption = description.decode()
    photo = r.hget('koltime_menu_bot', 'pic_url')
    if isinstance(photo, bytes):
        await update.message.reply_photo(
            photo=photo.decode(),
            caption=caption,
            reply_markup=reply_markup,
        )
    else:
        await update.message.reply_text(
            text=caption,
            reply_markup=reply_markup,
        )


async def pindao(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    pindao_dict: dict[str, list[tuple[str]]] = {}
    channels = r.zrange("koltime_menu_bot_channels", 0, 1000, withscores=True)
    for item in channels:
        pindao_list = pindao_dict.setdefault(score_dict[item[1]], [])
        pindao_list.append(tuple(item[0].decode().split(',')))

    text = f"{PINDAO_TEXT}👇\n"
    for k, v in pindao_dict.items():
        text += f'【{k}】\n'
        for v_item in v:
            text += f'[{v_item[1]}]({v_item[2]})\n'

        text += '\n'

    text = text.replace('-', '\\-')
    await update.message.reply_text(
        text,
        parse_mode='MarkdownV2')


async def faq(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    await update.message.reply_text('🍄开发中...')


async def xuexi(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    await update.message.reply_text('🍄开发中...')


async def shiyong(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    await update.message.reply_text('🍄开发中...')


async def vip(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    await update.message.reply_text('🍄开发中...')


async def fanyong(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    await update.message.reply_text('🍄开发中...')


async def qun(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    await update.message.reply_text('🍄开发中...')


def koltime_menu_bot(env_path: str = '.env') -> None:
    clean_session_files()
    dotenv.load_dotenv(env_path)
    global r
    if r is None:
        r = redis.Redis(
            host=os.getenv(f'{ENV_PREFIX}REDIS_HOST'),
            port=os.getenv(f'{ENV_PREFIX}REDIS_PORT'),
            password=os.getenv(f'{ENV_PREFIX}REDIS_PASSWORD'),
            db=0)

    proxy = os.getenv(f'{ENV_PREFIX}PROXY')
    token = os.getenv(f'{ENV_PREFIX}TOKEN')
    if proxy is None:
        application = (
            Application.builder()
            .token(token)
            .build()
        )
    else:
        application = (
            Application.builder()
            .proxy(proxy)
            .token(token)
            .build()
        )

    application.add_handler(CommandHandler("start", start))
    application.add_handler(MessageHandler(filters.Text(['?', FAQ_TEXT]), faq))
    application.add_handler(MessageHandler(filters.Text([PINDAO_TEXT]), pindao))
    application.add_handler(MessageHandler(filters.Text([XUEXI_TEXT]), xuexi))
    application.add_handler(MessageHandler(filters.Text([SHIYONG_TEXT]), shiyong))
    application.add_handler(MessageHandler(filters.Text([VIP_TEXT]), vip))
    application.add_handler(MessageHandler(filters.Text([FANYONG_TEXT]), fanyong))
    application.add_handler(MessageHandler(filters.Text([QUN_TEXT]), qun))
    try:
        print(f"✅ koltime_menu_bot start...,{datetime.now()}")
        application.run_polling(allowed_updates=Update.ALL_TYPES)
    except:
        pass


if __name__ == '__main__':
    koltime_menu_bot('d:/.env')



import re


def proxy_parse_tuple(proxy: str | None) -> tuple | None:
    if proxy is None:
        return None
    else:
        try:
            rst = re.split('://|:', proxy)
            if len(rst) != 3:
                return None
            rst[-1] = int(rst[-1])
            return tuple(rst)
        except:
            return None



"""Utility functions to smoothen your life."""

import logging
import os
import re
from datetime import datetime
from tg import config
from tg.plugin_models import STYLE_CODES


def cleanup(*files: str) -> None:
    """Delete the file names passed as args."""
    for file in files:
        try:
            os.remove(file)
        except FileNotFoundError:
            logging.info(f"File {file} does not exist, so cant delete it.")


def stamp(file: str, user: str) -> str:
    """Stamp the filename with the datetime, and user info."""
    now = str(datetime.now())
    outf = safe_name(f"{user} {now} {file}")
    try:
        os.rename(file, outf)
        return outf
    except Exception as err:
        logging.warning(f"Stamping file name failed for {file} to {outf}. \n {err}")


def safe_name(string: str) -> str:
    """Return safe file name.

    Certain characters in the file name can cause potential problems in rare scenarios.
    """
    return re.sub(pattern=r"[-!@#$%^&*()\s]", repl="_", string=string)


def match(pattern: str, string: str, regex: bool) -> bool:
    if regex:
        return bool(re.findall(pattern, string))
    return pattern in string


def replace(pattern: str, new: str, string: str, regex: bool) -> str:
    def fmt_repl(matched):
        style = new
        s = STYLE_CODES.get(style)
        return f"{s}{matched.group(0)}{s}"

    if regex:
        if new in STYLE_CODES:
            compliled_pattern = re.compile(pattern)
            return compliled_pattern.sub(repl=fmt_repl, string=string)
        return re.sub(pattern, new, string)
    else:
        return string.replace(pattern, new)


def clean_session_files():
    for item in os.listdir():
        if item.endswith(".session") or item.endswith(".session-journal"):
            os.remove(item)


def get_command_prefix():
    if config.is_bot is None:
        raise ValueError("config.is_bot is not set!")
    return "/" if config.is_bot else "\."


import asyncio
import json
from datetime import datetime, timedelta, timezone
import logging
import time
from telethon import TelegramClient
from telethon.errors.rpcerrorlist import FloodWaitError
from telethon.tl.custom.message import Message
from telethon.tl.patched import MessageService

from tg import config
from tg import storage as st
from tg.config import CONFIG, write_config
from tg.plugins import apply_plugins
from tg.message import send_message


async def forward_job(client: TelegramClient) -> None:
    me = await client.get_me()
    print(f'🛩️usd_id:{me.id}')
    print(f'🛩️usename:{me.username}')

    config.from_to = await config.load_from_to(client, config.CONFIG.forwards)
    forward: config.Forward
    time_diff = datetime.now(tz=timezone.utc) - timedelta(hours=1)
    while True:
        for from_to, forward in zip(config.from_to.items(), config.CONFIG.forwards):
            src, dest = from_to
            print(f'🛩️forwarding messages from 【{src}】 to {dest},offset_id:【{forward.offset}】')
            async for message in client.iter_messages(
                    src,
                    reverse=True,
                    offset_id=forward.offset,
                    offset_date=time_diff,
                    limit=100
            ):
                message: Message

                event = st.DummyEvent(message.chat_id, message.id)
                event_uid = st.EventUid(event)

                if isinstance(message, MessageService):
                    continue
                try:
                    tm = await apply_plugins(message)
                    if not tm:
                        continue
                    st.stored[event_uid] = {}

                    r_event_uid = None
                    if message.is_reply:
                        r_event = st.DummyEvent(
                            message.chat_id, message.reply_to_msg_id
                        )
                        r_event_uid = st.EventUid(r_event)
                    for d in dest:
                        if message.is_reply and r_event_uid in st.stored:
                            tm.reply_to = st.stored.get(r_event_uid).get(d)
                        fwded_msg = await send_message(d, tm)
                        st.stored[event_uid].update({d: fwded_msg.id})
                    tm.clear()
                    last_id = message.id
                    logging.info(f"forwarding message with id = {last_id}")
                    forward.offset = last_id
                    write_config(CONFIG, persist=False)
                    time.sleep(CONFIG.past.delay)
                    logging.info(f"slept for {CONFIG.past.delay} seconds")

                except FloodWaitError as fwe:
                    logging.info(f"Sleeping for {fwe}")
                    await asyncio.sleep(delay=fwe.seconds)
                except Exception as err:
                    logging.exception(err)

        time.sleep(60)



import inspect
import logging
from importlib import import_module
from typing import Any, Dict

from telethon.tl.custom.message import Message

from tg.config import CONFIG
from tg.message import TgMessage

PLUGINS = CONFIG.plugins


class TgPlugin:
    id_ = "plugin"

    def __init__(self, data: Dict[str, Any]) -> None:
        self.data = data

    def modify(self, tm: TgMessage) -> TgMessage:
        """Modify the message here."""
        return tm


def load_plugins() -> Dict[str, TgPlugin]:
    """Load the plugins specified in config."""
    _plugins = {}
    for item in PLUGINS:
        plugin_id = item[0]
        if not item[1].check:
            continue

        plugin_class_name = f"Tg{plugin_id.title()}"
        plugin_module = None
        try:  # try to load first party plugin
            plugin_module = import_module("tg.plugins." + plugin_id)
        except ModuleNotFoundError:
            logging.error(
                f"{plugin_id} is not a first party plugin. Third party plugins are not supported."
            )
        else:
            logging.info(f"First party plugin {plugin_id} loaded!")

        try:
            plugin_class = getattr(plugin_module, plugin_class_name)
            if not issubclass(plugin_class, TgPlugin):
                logging.error(
                    f"Plugin class {plugin_class_name} does not inherit TgPlugin"
                )
                continue
            plugin: TgPlugin = plugin_class(item[1])
            if not plugin.id_ == plugin_id:
                logging.error(f"Plugin id for {plugin_id} does not match expected id.")
                continue
        except AttributeError:
            logging.error(f"Found plugin {plugin_id}, but plguin class not found.")
        else:
            logging.info(f"Loaded plugin {plugin_id}")
            _plugins.update({plugin.id_: plugin})
    return _plugins


async def apply_plugins(message: Message) -> TgMessage | None:
    """Apply all loaded plugins to a message."""
    tm = TgMessage(message)

    for _id, plugin in plugins.items():
        try:
            if inspect.iscoroutinefunction(plugin.modify):
                ntm = await plugin.modify(tm)
            else:
                ntm = plugin.modify(tm)
        except Exception as err:
            logging.error(f"Failed to apply plugin {_id}. \n {err} ")
        else:
            logging.info(f"Applied plugin {_id}")
            if not ntm:
                tm.clear()
                return None
    return tm


plugins = load_plugins()



import logging
from tg.plugin_models import STYLE_CODES, Style
from tg.plugins import TgMessage, TgPlugin


class TgFmt(TgPlugin):
    id_ = "fmt"

    def __init__(self, data) -> None:
        super().__init__(data)
        self.format = self.data
        logging.info(self.format)

    def modify(self, tm: TgMessage) -> TgMessage:
        if self.format['style'] is Style.PRESERVE:
            return tm
        msg_text: str = tm.raw_text
        if not msg_text:
            return tm
        style = STYLE_CODES.get(self.format['style'])
        tm.text = f"{style}{msg_text}{style}"
        return tm



from tests import *
import os
import redis

if __name__ == '__main__':
    r = redis.Redis(
        host='127.0.0.1',
        port=6379,
        password=os.getenv('REDIS_PASSWORD'),
        db=0)

    pindao_dict: dict[str, list[tuple[str]]] = {}
    score_dict: dict[float, str] = {
        1.0: '中文博主',
        2.0: '提阿非罗',
        3.0: '英文博主',
        4.0: 'koltime'
    }

    channels = r.zrange("sorted_channels", 0, 1000, withscores=True)
    for item in channels:
        pindao = pindao_dict.setdefault(score_dict[item[1]], [])
        pindao.append(tuple(item[0].decode().split(',')))

        # print(item)
        # print(type(item[1]))
        # channel_info = item[0].decode().split(',')
        # print(channel_info[1], channel_info[2])

    text = "📚频道列表👇\n"
    for k, v in pindao_dict.items():
        text += f'【{k}】\n'
        for v_item in v:
            text += f'[{v_item[1]}]({v_item[2]})\n'

        text += '\n'

    print(text)



import logging
from tg.plugins import TgMessage, TgPlugin
from tg.utils import replace


class TgReplace(TgPlugin):
    id_ = "replace"

    def __init__(self, data):
        super().__init__(data)
        self.replace = self.data
        logging.info(self.replace)

    def modify(self, tm: TgMessage) -> TgMessage:
        msg_text: str = tm.text
        if not msg_text:
            return tm
        for original, new in self.replace.text.items():
            msg_text = replace(original, new, msg_text, self.replace.regex)
        tm.text = msg_text
        return tm



import logging
import os
from typing import List, Tuple, cast

from telegram import InlineKeyboardButton, InlineKeyboardMarkup, Update
from telegram.ext import (
    Application,
    CallbackQueryHandler,
    CommandHandler,
    ContextTypes,
    InvalidCallbackData,
    PicklePersistence,
)

# Enable logging
logging.basicConfig(
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s", level=logging.INFO
)
# set higher logging level for httpx to avoid all GET and POST requests being logged
logging.getLogger("httpx").setLevel(logging.WARNING)

logger = logging.getLogger(__name__)


async def start(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    """Sends a message with 5 inline buttons attached."""
    number_list: List[int] = []
    await update.message.reply_text("Please choose:", reply_markup=build_keyboard(number_list))


async def help_command(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    """Displays info on how to use the bot."""
    await update.message.reply_text(
        "Use /start to test this bot. Use /clear to clear the stored data so that you can see "
        "what happens, if the button data is not available. "
    )


async def clear(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    """Clears the callback data cache"""
    context.bot.callback_data_cache.clear_callback_data()
    context.bot.callback_data_cache.clear_callback_queries()
    await update.effective_message.reply_text("All clear!")


def build_keyboard(current_list: List[int]) -> InlineKeyboardMarkup:
    """Helper function to build the next inline keyboard."""
    return InlineKeyboardMarkup.from_column(
        [InlineKeyboardButton(str(i), callback_data=(i, current_list)) for i in range(1, 6)]
    )


async def list_button(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    """Parses the CallbackQuery and updates the message text."""
    query = update.callback_query
    await query.answer()
    # Get the data from the callback_data.
    # If you're using a type checker like MyPy, you'll have to use typing.cast
    # to make the checker get the expected type of the callback_data
    number, number_list = cast(Tuple[int, List[int]], query.data)
    # append the number to the list
    number_list.append(number)

    await query.edit_message_text(
        text=f"So far you've selected {number_list}. Choose the next item:",
        reply_markup=build_keyboard(number_list),
    )

    # we can delete the data stored for the query, because we've replaced the buttons
    context.drop_callback_data(query)


async def handle_invalid_button(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
    """Informs the user that the button is no longer available."""
    await update.callback_query.answer()
    await update.effective_message.edit_text(
        "Sorry, I could not process this button click 😕 Please send /start to get a new keyboard."
    )


def main() -> None:
    """Run the bot."""
    # We use persistence to demonstrate how buttons can still work after the bot was restarted
    persistence = PicklePersistence(filepath="arbitrarycallbackdatabot")
    # Create the Application and pass it your bot's token.
    application = (
        Application.builder()
        .proxy("http://127.0.0.1:7890")
        .token(os.getenv("TG_B49_BOT_TOKEN"))
        .persistence(persistence)
        .arbitrary_callback_data(True)
        .build()
    )

    application.add_handler(CommandHandler("start", start))
    application.add_handler(CommandHandler("help", help_command))
    application.add_handler(CommandHandler("clear", clear))
    application.add_handler(
        CallbackQueryHandler(handle_invalid_button, pattern=InvalidCallbackData)
    )
    application.add_handler(CallbackQueryHandler(list_button))

    # Run the bot until the user presses Ctrl-C
    application.run_polling(allowed_updates=Update.ALL_TYPES)


if __name__ == "__main__":
    main()



import os

from rich import console, traceback

con = console.Console()

if __name__ == '__main__':
    con.print(
        f"tg forward has a newer release v1.0.1 availaible!\
                \nVisit http://feicrypto.top",
        style="bold yellow",
    )
    con.print(os.getcwd(), style="blue")
    con.print(os.listdir(), style="green")



import base64
import os
import requests
from dotenv import load_dotenv

load_dotenv('d:/.env')

if __name__ == "__main__":
    dir_path = os.path.dirname(os.path.abspath(__file__))
    file_path = os.path.join(dir_path, './captcha.jpg')
    with open(file_path, 'rb') as f:
        b64_string = base64.b64encode(f.read()).decode('utf-8')
    print(b64_string)
    host = 'https://yzmcolor.market.alicloudapi.com'
    request_path = '/yzmSpeed'
    method = 'POST'
    appcode = os.getenv('ALIYUN_OCR_APPCODE')
    url = host + request_path
    header = {'Authorization': 'APPCODE ' + appcode, "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"}
    data = {
        'pri_id': 'dn',
        'v_pic': b64_string
    }
    resp = requests.post(url, data=data, headers=header)
    print('-' * 50)
    print("status_code:{0}".format(resp.status_code))
    print("resp_text:{0}".format(resp.text))
    print("resp_json:{0}".format(resp.json()))
    print("resp_json:{0}".format(resp.json()['v_code']))
    print("resp_json:{0}".format(resp.json()['msg']))
    print("resp_json:{0}".format(resp.json()['errCode']))



import base64
import os

if __name__ == '__main__':
    print(os.getcwd())
    current_path = os.path.dirname(os.path.abspath(__file__))
    print(current_path)  # 获取当前 Python 脚本所在的路径)
    file_path = os.path.join(current_path, './captcha.jpg')  # 拼接相对路径
    print(file_path)
    with open(file_path, 'rb') as f:
        b64_string = base64.b64encode(f.read())
    print(b64_string.decode('utf-8'))

    print(os.path.basename('e:/github/feicrypto/fei-crypto-python/media/videos/360p15/btc.mp4'))



from typing import Optional
import typer
from .login import login
from rich import console

from fei_crypto import __version__


tg_login_app = typer.Typer(add_completion=False)

con = console.Console()


def version_callback(value: bool):
    """Show current version and exit."""

    if value:
        con.print(__version__)
        raise typer.Exit()


@tg_login_app.command()
def main(
        api_id: int = typer.Option(
            ...,
            "--API_ID",
            help="API ID obtained from my.telegram.org",
            # envvar="TG_LOGIN_API_ID",
            prompt="Paste your API ID (input hidden)",
            hide_input=False,
        ),
        api_hash: str = typer.Option(
            ...,
            "--API_HASH",
            help="API HASH obtained from my.telegram.org",
            # envvar="TG_LOGIN_API_HASH",
            prompt="Paste your API HASH (input hidden)",
            hide_input=False,
        ),
        proxy: str = typer.Option(
            # proxy: str = typer.Option(
            "",
            "--PROXY",
            help="Set proxy.",
            # envvar="TG_LOGIN_PROXY",
            prompt="Optional! paste your proxy example:socks5://127.0.0.1:7890;",
            hide_input=False,
        ),
        version: Optional[bool] = typer.Option(  # pylint: disable=unused-argument
            None,
            "--version",
            "-v",
            callback=version_callback,
            help="Show version and exit.",
        ),
):
    """ A command line tool to login into Telegram with user or bot accounts. """

    login(api_id, api_hash, proxy)



from manim import *
import random

color_list = [
    BLUE_A,
    BLUE_B,
    BLUE_C,
    BLUE_D,
    BLUE_E,
    PURE_BLUE,
    BLUE,
    DARK_BLUE,
    TEAL_A,
    TEAL_B,
    TEAL_C,
    TEAL_D,
    TEAL_E,
    TEAL,
    GREEN_A,
    GREEN_B,
    GREEN_C,
    GREEN_D,
    GREEN_E,
    PURE_GREEN,
    GREEN,
    YELLOW_A,
    YELLOW_B,
    YELLOW_C,
    YELLOW_D,
    YELLOW_E,
    YELLOW,
    GOLD_A,
    GOLD_B,
    GOLD_C,
    GOLD_D,
    GOLD_E,
    GOLD,
    RED_A,
    RED_B,
    RED_C,
    RED_D,
    RED_E,
    PURE_RED,
    RED,
    MAROON_A,
    MAROON_B,
    MAROON_C,
    MAROON_D,
    MAROON_E,
    MAROON,
    PURPLE_A,
    PURPLE_B,
    PURPLE_C,
    PURPLE_D,
    PURPLE_E,
    PURPLE,
    PINK,
    LIGHT_PINK,
    ORANGE,
    LIGHT_BROWN,
    DARK_BROWN,
    LOGO_GREEN,
    LOGO_BLUE,
    LOGO_RED,
]


class T2M(Scene):
    def __init__(self, t: str, n: int = 0):
        config["pixel_width"] = 960
        config["pixel_height"] = 360

        super().__init__()
        t2c_dict: dict = {}
        for i, c in enumerate(t):
            if c != ' ':
                # r_color = random_bright_color()
                # r_color = random_color()
                # if str(r_color) == '#000000':
                #     r_color = '#ffffff'

                r_color = random.choice(color_list)

                t2c_dict['[{0}:{1}]'.format(i, i + 1)] = r_color

        mtext = Text(t, t2c=t2c_dict, fill_opacity=1, weight='BOLD')
        if n == 1:
            # self.play(Write(mtext.shift(DOWN * 1)))
            self.play(Write(mtext))
        else:
            self.play(Create(mtext))

        self.play(mtext.animate.scale(2))

        self.wait()


def t2m(text: str, out_filename: str = "t2m", quality: str = "low_quality", out_format: str = 'gif',
        style: int = 0, preview: bool = False):
    with tempconfig(
            {'output_file': out_filename, 'quality': quality, 'format': out_format, 'preview': preview}):
        scene = T2M(t=text, n=style)
        scene.render()


if __name__ == '__main__':
    t2m("BTC-USDT")



import logging
import os

from telegram import InlineKeyboardButton, InlineKeyboardMarkup, Update
from telegram.ext import (
    Application,
    CallbackQueryHandler,
    CommandHandler,
    ContextTypes,
    ConversationHandler,
)

from tests import *

# Enable logging
logging.basicConfig(
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s", level=logging.INFO
)
# set higher logging level for httpx to avoid all GET and POST requests being logged
logging.getLogger("httpx").setLevel(logging.WARNING)

logger = logging.getLogger(__name__)

# Stages
START_ROUTES, END_ROUTES = range(2)
# Callback data
ONE, TWO, THREE, FOUR = range(4)


async def start(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
    """Send message on `/start`."""
    # Get user that sent /start and log his name
    user = update.message.from_user
    logger.info("User %s started the conversation.", user.first_name)
    # Build InlineKeyboard where each button has a displayed text
    # and a string as callback_data
    # The keyboard is a list of button rows, where each row is in turn
    # a list (hence `[[...]]`).
    keyboard = [
        [
            InlineKeyboardButton("1", callback_data=str(ONE)),
            InlineKeyboardButton("2", callback_data=str(TWO)),
        ]
    ]
    reply_markup = InlineKeyboardMarkup(keyboard)
    # Send message with text and appended InlineKeyboard
    await update.message.reply_text("Start handler, Choose a route", reply_markup=reply_markup)
    # Tell ConversationHandler that we're in state `FIRST` now
    return START_ROUTES


async def start_over(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
    """Prompt same text & keyboard as `start` does but not as new message"""
    # Get CallbackQuery from Update
    query = update.callback_query
    # CallbackQueries need to be answered, even if no notification to the user is needed
    # Some clients may have trouble otherwise. See https://core.telegram.org/bots/api#callbackquery
    await query.answer()
    keyboard = [
        [
            InlineKeyboardButton("1", callback_data=str(ONE)),
            InlineKeyboardButton("2", callback_data=str(TWO)),
        ]
    ]
    reply_markup = InlineKeyboardMarkup(keyboard)
    # Instead of sending a new message, edit the message that
    # originated the CallbackQuery. This gives the feeling of an
    # interactive menu.
    await query.edit_message_text(text="Start handler, Choose a route", reply_markup=reply_markup)
    return START_ROUTES


async def one(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
    """Show new choice of buttons"""
    query = update.callback_query
    await query.answer()
    keyboard = [
        [
            InlineKeyboardButton("3", callback_data=str(THREE)),
            InlineKeyboardButton("4", callback_data=str(FOUR)),
        ]
    ]
    reply_markup = InlineKeyboardMarkup(keyboard)
    await query.edit_message_text(
        text="First CallbackQueryHandler, Choose a route", reply_markup=reply_markup
    )
    return START_ROUTES


async def two(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
    """Show new choice of buttons"""
    query = update.callback_query
    await query.answer()
    keyboard = [
        [
            InlineKeyboardButton("1", callback_data=str(ONE)),
            InlineKeyboardButton("3", callback_data=str(THREE)),
        ]
    ]
    reply_markup = InlineKeyboardMarkup(keyboard)
    await query.edit_message_text(
        text="Second CallbackQueryHandler, Choose a route", reply_markup=reply_markup
    )
    return START_ROUTES


async def three(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
    """Show new choice of buttons. This is the end point of the conversation."""
    query = update.callback_query
    await query.answer()
    keyboard = [
        [
            InlineKeyboardButton("Yes, let's do it again!", callback_data=str(ONE)),
            InlineKeyboardButton("Nah, I've had enough ...", callback_data=str(TWO)),
        ]
    ]
    reply_markup = InlineKeyboardMarkup(keyboard)
    await query.edit_message_text(
        text="Third CallbackQueryHandler. Do want to start over?", reply_markup=reply_markup
    )
    # Transfer to conversation state `SECOND`
    return END_ROUTES


async def four(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
    """Show new choice of buttons"""
    query = update.callback_query
    await query.answer()
    keyboard = [
        [
            InlineKeyboardButton("2", callback_data=str(TWO)),
            InlineKeyboardButton("3", callback_data=str(THREE)),
        ]
    ]
    reply_markup = InlineKeyboardMarkup(keyboard)
    await query.edit_message_text(
        text="Fourth CallbackQueryHandler, Choose a route", reply_markup=reply_markup
    )
    return START_ROUTES


async def end(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
    """Returns `ConversationHandler.END`, which tells the
    ConversationHandler that the conversation is over.
    """
    query = update.callback_query
    await query.answer()
    await query.edit_message_text(text="See you next time!")
    return ConversationHandler.END


def main() -> None:
    """Run the bot."""
    # Create the Application and pass it your bot's token.
    application = Application.builder().token(os.getenv("TG_B49_BOT_TOKEN")).build()

    # Setup conversation handler with the states FIRST and SECOND
    # Use the pattern parameter to pass CallbackQueries with specific
    # data pattern to the corresponding handlers.
    # ^ means "start of line/string"
    # $ means "end of line/string"
    # So ^ABC$ will only allow 'ABC'
    conv_handler = ConversationHandler(
        entry_points=[CommandHandler("start", start)],
        states={
            START_ROUTES: [
                CallbackQueryHandler(one, pattern="^" + str(ONE) + "$"),
                CallbackQueryHandler(two, pattern="^" + str(TWO) + "$"),
                CallbackQueryHandler(three, pattern="^" + str(THREE) + "$"),
                CallbackQueryHandler(four, pattern="^" + str(FOUR) + "$"),
            ],
            END_ROUTES: [
                CallbackQueryHandler(start_over, pattern="^" + str(ONE) + "$"),
                CallbackQueryHandler(end, pattern="^" + str(TWO) + "$"),
            ],
        },
        fallbacks=[CommandHandler("start", start)],
    )

    # Add ConversationHandler to application that will be used for handling updates
    application.add_handler(conv_handler)

    # Run the bot until the user presses Ctrl-C
    application.run_polling(allowed_updates=Update.ALL_TYPES)


if __name__ == "__main__":
    main()



from enum import Enum


class TestType(Enum):
    AUDIO = "audio"
    GIF = "gif"
    VIDEO = "video"
    VIDEO_NOTE = "video_note"
    STICKER = "sticker"
    CONTACT = "contact"
    PHOTO = "photo"
    DOCUMENT = "document"
    NOFILE = "nofile"


if __name__ == '__main__':
    for f in TestType:
        print(f)
        print(f.value)
        print(type(f.value))
        # if f == TestType.NOFILE:
        #     print(TestType.NOFILE)



import base64

import typer
import requests


def captcha(file_abs_path: str, aliyun_ocr_appcode: str, pri_id='dn') -> str:
    with open(file_abs_path, 'rb') as f:
        b64_string = base64.b64encode(f.read()).decode('utf-8')

    host = 'https://yzmcolor.market.alicloudapi.com'
    request_path = '/yzmSpeed'
    url = host + request_path
    header = {'Authorization': 'APPCODE ' + aliyun_ocr_appcode,
              "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"}
    data = {
        'pri_id': pri_id,
        'v_pic': b64_string
    }
    resp = requests.post(url, data=data, headers=header)
    if resp.status_code != 200:
        return ''
    try:
        v_code = resp.json()['v_code']
        print(v_code)
        return v_code
    except:
        return ''


if __name__ == '__main__':
    typer.run(captcha)



"""Declare all global constants."""

COMMANDS = {
    "start": "Check whether I am alive",
    "forward": "Set a new forward",
    "remove": "Remove an existing forward",
    "help": "Learn usage",
}

REGISTER_COMMANDS = True
# 缓存保留消息条数
KEEP_LAST_MANY = 10000

MONGO_DB_NAME = "tg-config"
MONGO_COL_NAME = "tg-instance-0"



from typing import Tuple, Dict, Any

from pydantic.main import BaseModel


class TestCaption(BaseModel):
    check: bool = False
    header: str = ""
    footer: str = ""


class TestTuple(BaseModel):
    ok: bool = True
    caption: TestCaption = TestCaption()


class TestModel:
    id_ = "plugin"

    def __init__(self, data: Dict[str, Any]) -> None:
        self.data = data


if __name__ == '__main__':
    def fun_a(a: Tuple[str, int]) -> Tuple:
        return a


    r = fun_a(('aa', 12))
    print(r)
    for item in TestTuple():
        print(type(item[1]))
        print(type(item))
        print(item)
        print('-' * 50)
        # print(item)
        # print(item[0], item[1])
        # print(type(item))

    tinydict = {'Name': 'Zara', 'Age': 7, 'Class': 'First'}
    for item in tinydict:
        print(type(item))
        print(item)
        print('-' * 50)



import logging
from typing import Dict, Any
from tg.plugins import TgMessage, TgPlugin


class TgCaption(TgPlugin):
    id_ = "caption"

    def __init__(self, data: Dict[str, Any]) -> None:
        super().__init__(data)
        self.caption = self.data
        logging.info(self.caption)

    def modify(self, tm: TgMessage) -> TgMessage:
        tm.text = f"{self.caption['header']}{tm.text}{self.caption['footer']}"
        return tm



import logging
import sys
from enum import Enum
from typing import Optional

import typer
from rich import console, traceback
from rich.logging import RichHandler
from verlat import latest_release

from fei_crypto import __version__
from tg import config
from telethon import TelegramClient
from tg import storage as stg

from tg.parse import proxy_parse_tuple
from tg.utils import clean_session_files

tg_forward_app = typer.Typer(add_completion=False)
con = console.Console()
TG_CONFIG_FILE_NAME = ""


def topper():
    version_check()
    print("\n")


class Mode(str, Enum):
    """works in two modes."""

    PAST = "past"
    LIVE = "live"


def verbosity_callback(value: bool):
    """Set logging level."""
    traceback.install()
    if value:
        level = logging.INFO
    else:
        level = logging.WARNING
    logging.basicConfig(
        level=level,
        format="%(message)s",
        handlers=[
            RichHandler(
                rich_tracebacks=True,
                markup=True,
            )
        ],
    )
    topper()
    logging.info("Verbosity turned on! This is suitable for debugging")


def version_callback(value: bool):
    """Show current version and exit."""

    if value:
        con.print(__version__)
        raise typer.Exit()


def version_check():
    latver = latest_release("fei-crypto").version
    if __version__ != latver:
        con.print(
            f"fei-crypto.tgf has a newer release {latver} availaible!\
            \nVisit https://pypi.org/project/fei-crypto",
            style="bold yellow",
        )
    else:
        con.print(f"Running latest fei-crypto.tgf version {__version__}", style="bold green")


@tg_forward_app.command()
def main(
        mode: Mode = typer.Argument(
            ..., help="Choose the mode in which you want to run fei-crypto.tgf",
            # envvar="TGF_MODE"
        ),
        config_path: str = typer.Option(
            'tg.config.json',
            '--config-path',
            '-c',
            help='config file path,default:\"tg.config.json\"',
        ),
        verbose: Optional[bool] = typer.Option(  # pylint: disable=unused-argument
            None,
            "--loud",
            "-l",
            callback=verbosity_callback,
            # envvar="LOUD",
            help="Increase output verbosity.",
        ),
        version: Optional[bool] = typer.Option(  # pylint: disable=unused-argument
            None,
            "--version",
            "-v",
            callback=version_callback,
            help="Show version and exit.",
        ),
):
    clean_session_files()
    config.CONFIG_FILE_NAME = config_path
    stg.CONFIG_TYPE = config.detect_config_type()
    config.CONFIG = config.read_config()

    session = config.get_session()

    if mode == Mode.PAST and config.CONFIG.login.user_type != 1:
        logging.warning(
            "You cannot use bot account for tgf past mode. Telegram does not allow bots to access chat history."
        )
        return

    client = TelegramClient(
        session,
        config.CONFIG.login.API_ID,
        config.CONFIG.login.API_HASH,
        sequential_updates=config.CONFIG.live.sequential_updates,
        proxy=proxy_parse_tuple(config.CONFIG.login.PROXY)
    )
    if config.CONFIG.login.user_type == 0:
        if config.CONFIG.login.BOT_TOKEN == "":
            logging.warning("Bot token not found, but login type is set to bot.")
            sys.exit()
        client.start(bot_token=config.CONFIG.login.BOT_TOKEN)

    if mode == Mode.PAST:
        from tg.past import forward_job
        with client:
            client.loop.run_until_complete(forward_job(client))
        pass
    elif mode == Mode.LIVE:
        from tg.live import start_sync
        with client:
            client.loop.run_until_complete(start_sync(client))



from enum import Enum
from typing import Dict, List

from pydantic import BaseModel


class FileType(Enum):
    AUDIO = "audio"
    GIF = "gif"
    VIDEO = "video"
    VIDEO_NOTE = "video_note"
    STICKER = "sticker"
    CONTACT = "contact"
    PHOTO = "photo"
    DOCUMENT = "document"
    NOFILE = "nofile"


class FilterList(BaseModel):
    blacklist: List[str] = []
    whitelist: List[str] = []


class FilesFilterList(BaseModel):
    blacklist: List[FileType] = []
    whitelist: List[FileType] = []


class TextFilter(FilterList):
    case_sensitive: bool = False
    regex: bool = False


class Style(str, Enum):
    BOLD = "bold"
    ITALICS = "italics"
    CODE = "code"
    STRIKE = "strike"
    PLAIN = "plain"
    PRESERVE = "preserve"


STYLE_CODES = {"bold": "**", "italics": "__", "code": "`", "strike": "~~", "plain": ""}


# define plugin configs


class Filters(BaseModel):
    check: bool = False
    users: FilterList = FilterList()
    files: FilesFilterList = FilesFilterList()
    text: TextFilter = TextFilter()


class Format(BaseModel):
    check: bool = False
    style: Style = Style.PRESERVE


class Replace(BaseModel):
    check: bool = False
    text: Dict[str, str] = {}
    text_raw: str = ""
    regex: bool = False


class Caption(BaseModel):
    check: bool = False
    header: str = ""
    footer: str = ""


class PluginConfig(BaseModel):
    filter: Filters = Filters()
    fmt: Format = Format()
    replace: Replace = Replace()
    caption: Caption = Caption()



import platform


def os():
    match platform.system():
        case 'Linux':
            print('linux')
            # signal.pause()
        case 'Windows':
            print('Windows')
            # os.system('pause')
        case _:
            print('other')

if __name__ == '__main__':
    os()

